@@ -54,17 +54,13 @@ ExecWindow::ExecWindow(watchCond *wc, int pid, QString cmd)
     pr = new QProcess;          // leak?
     if (!wc->command.isEmpty()) // conflict pid's command
     {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
         QStringList args = QProcess::splitCommand(wc->command);
         pr->start(args.takeFirst(), args); // thread run, if null then segfault occurs. ?
-#else
-        pr->start(wc->command); // thread run, if null then segfault occurs. ?
-#endif
     }
 
-    connect(okButton, SIGNAL(clicked()), this, SLOT(cmd_ok()));
+    connect(okButton, &QAbstractButton::clicked, this, &ExecWindow::cmd_ok);
 
-    connect(pr, SIGNAL(started()), this, SLOT(cmd_started()));
+    connect(pr, &QProcess::started, this, &ExecWindow::cmd_started);
     connect(pr, SIGNAL(finished(int, QProcess::ExitStatus)), this,
             SLOT(cmd_finished(int, QProcess::ExitStatus)));
     connect(pr, SIGNAL(error(QProcess::ProcessError)), this,
