@@ -772,8 +772,8 @@ HeadedTable::HeadedTable(QWidget *parent, int /*opts*/) : QWidget(parent)
     setLayout(vlayout);
 
     // synchronize horizontal scrolling of head and body
-    connect(body->horizontalScrollBar(), SIGNAL(valueChanged(int)), head,
-            SLOT(scrollSideways(int)));
+    connect(body->horizontalScrollBar(), &QAbstractSlider::valueChanged, head,
+            &TableHead::scrollSideways);
 
     // NOTE: It isn't enough to consider the font here because it may change at startup.
     // Instead, it will be taken into account when QEvent::FontChange() is sent.
@@ -840,34 +840,6 @@ inline int HeadedTable::colXPos(int col)
     return x;
 }
 
-// repaint columns from col0 to col1. If col1 is -1, repaint all
-// the way to the right edge of the table.
-// called by
-//          1.void Qps::update_table(int col)
-void HeadedTable::repaintColumns(int col0, int col1)
-{
-    QRect bvr = body->viewRect();
-    QRect hvr = head->viewRect();
-    int x0 = colOffset(col0) - body->xOffset();
-    if (x0 > hvr.width())
-        return;
-    if (x0 < 0)
-        x0 = 0;
-    bvr.setLeft(x0);
-    hvr.setLeft(x0);
-    if (col1 >= 0)
-    {
-        int x1 = colOffset(col1) + max_widths[col1] - body->xOffset();
-        if (x1 < hvr.width())
-        {
-            hvr.setRight(x1);
-            bvr.setRight(x1);
-        }
-    }
-    head->repaint(hvr);
-    body->repaint(bvr);
-}
-
 // DEL -> virtual
 // 	called by Pstable::setTreeMode(bool)
 void HeadedTable::setTreeMode(bool tm)
@@ -888,7 +860,12 @@ int HeadedTable::tableWidth() const
 // update table Head !!
 void HeadedTable::setSortedCol(int col)
 {
+    int old_sorted_col = sorted_col;
     sorted_col = col;
+    // repaint the previously sorted header section to make sure that
+    // its sort indicator is removed (see QtTableView::repaintCell())
+    if (old_sorted_col != sorted_col && old_sorted_col > -1 && old_sorted_col < ncols)
+        head->repaintCell(0, old_sorted_col);
 }
 
 // should be virtual. why?
@@ -1026,11 +1003,7 @@ void HeadedTable::updateColWidth(int col)
 
     for (int i = 0; i < rows; i++)
     {
-#if (QT_VERSION >= QT_VERSION_CHECK(5,11,0))
         sw = fontMetrics().horizontalAdvance(text(i, col)) + 10;
-#else
-        sw = fontMetrics().width(text(i, col)) + 10;
-#endif
         if (treecol)
             sw += treestep * rowDepth(i);
         if (sw > w)
