@@ -27,22 +27,12 @@
 
 #include <LXQt/SingleApplication>
 
-// MOD!!!: For systray update.
-// this trick very suck, but I can't find a better solution.
 class QpsApp : public LXQt::SingleApplication
 {
   public:
     QpsApp(int &argc, char **argv) : LXQt::SingleApplication(argc, argv){};
     void commitData(QSessionManager &sm);
     void saveState(QSessionManager &manager);
-
-    /*
-        virtual bool x11EventFilter ( XEvent *xev ){
-                // catch X11 event for systray_update !! which event?
-                ///if(trayicon!=NULL) return
-       trayicon->checkNewTrayEvent(xev);
-                return false; // events to qt.
-        }; */
 };
 
 #endif // QPSAPP_H
