@@ -221,42 +221,42 @@ ha sortit amb l&apos;estat </translation>
 <context>
     <name>ControlBar</name>
     <message>
-        <location filename="../misc.cpp" line="806"/>
+        <location filename="../misc.cpp" line="758"/>
         <source>Linear</source>
         <translation>Lineal</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="809"/>
+        <location filename="../misc.cpp" line="761"/>
         <source>Tree</source>
         <translation>Arbre</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="818"/>
+        <location filename="../misc.cpp" line="770"/>
         <source>Thread</source>
         <translation>Fil</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="825"/>
+        <location filename="../misc.cpp" line="777"/>
         <source>All Processes</source>
         <translation>Tots els processos</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="826"/>
+        <location filename="../misc.cpp" line="778"/>
         <source>Your Processes</source>
         <translation>Els vostres processos</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="827"/>
+        <location filename="../misc.cpp" line="779"/>
         <source>Non-Root Processes</source>
         <translation>Els processos que no siguin de root</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="828"/>
+        <location filename="../misc.cpp" line="780"/>
         <source>Running Processes</source>
         <translation>Els processos en execució</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="844"/>
+        <location filename="../misc.cpp" line="796"/>
         <source>Pause (Ctrl+Space)</source>
         <translation>Pausa (Ctrl+Espai)</translation>
     </message>
@@ -1348,7 +1348,7 @@ ha sortit amb l&apos;estat </translation>
     <message>
         <location filename="../qps.cpp" line="468"/>
         <source>Terminate</source>
-        <translation></translation>
+        <translation>Termina</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="470"/>
@@ -1370,6 +1370,11 @@ ha sortit amb l&apos;estat </translation>
         <source>Continue</source>
         <translation>Continua</translation>
     </message>
+    <message>
+        <location filename="../qps.cpp" line="477"/>
+        <source>Other Signals</source>
+        <translation>Altres senyals</translation>
+    </message>
     <message>
         <location filename="../qps.cpp" line="478"/>
         <source>SIGINT (interrupt)</source>
@@ -1473,7 +1478,7 @@ ha sortit amb l&apos;estat </translation>
     <message>
         <location filename="../qps.cpp" line="804"/>
         <source>Include Child Times</source>
-        <translation type="unfinished">Inclou el temps d&apos;execució dels processos fills</translation>
+        <translation>Inclou els temps dels processos fills</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="998"/>
@@ -1627,12 +1632,12 @@ ha sortit amb l&apos;estat </translation>
 <context>
     <name>SearchBox</name>
     <message>
-        <location filename="../misc.cpp" line="760"/>
+        <location filename="../misc.cpp" line="712"/>
         <source>PID, COMMAND, USER...</source>
         <translation type="unfinished">IDENTIFICADOR DE PROCÉS, ORDRE, USUARI...</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="761"/>
+        <location filename="../misc.cpp" line="713"/>
         <source>Filter</source>
         <translation>Filtre</translation>
     </message>
@@ -1752,7 +1757,7 @@ ha sortit amb l&apos;estat </translation>
 <context>
     <name>StatusBar</name>
     <message>
-        <location filename="../misc.cpp" line="796"/>
+        <location filename="../misc.cpp" line="748"/>
         <source>Process count: %1</source>
         <translation>Nombre de processos: %1</translation>
     </message>
