@@ -122,7 +122,7 @@ failed with the error:
     <message>
         <location filename="../command.cpp" line="215"/>
         <source>Too many processes</source>
-        <translation>Πολυάριθμες διεργασίες</translation>
+        <translation>Υπεράριθμες διεργασίες</translation>
     </message>
     <message>
         <location filename="../command.cpp" line="218"/>
@@ -221,42 +221,42 @@ exited with status </source>
 <context>
     <name>ControlBar</name>
     <message>
-        <location filename="../misc.cpp" line="806"/>
+        <location filename="../misc.cpp" line="758"/>
         <source>Linear</source>
         <translation>Γραμμική</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="809"/>
+        <location filename="../misc.cpp" line="761"/>
         <source>Tree</source>
         <translation>Δέντρο</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="818"/>
+        <location filename="../misc.cpp" line="770"/>
         <source>Thread</source>
         <translation>Νήμα</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="825"/>
+        <location filename="../misc.cpp" line="777"/>
         <source>All Processes</source>
         <translation>Όλες οι διεργασίες</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="826"/>
+        <location filename="../misc.cpp" line="778"/>
         <source>Your Processes</source>
         <translation>Οι διεργασίες σας</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="827"/>
+        <location filename="../misc.cpp" line="779"/>
         <source>Non-Root Processes</source>
         <translation>Διεργασίες μη root</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="828"/>
+        <location filename="../misc.cpp" line="780"/>
         <source>Running Processes</source>
         <translation>Τρέχουσες διεργασίες</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="844"/>
+        <location filename="../misc.cpp" line="796"/>
         <source>Pause (Ctrl+Space)</source>
         <translation>Παύση (Ctrl+Διάστημα)</translation>
     </message>
@@ -1071,7 +1071,7 @@ exited with status </source>
     <message>
         <location filename="../proc.cpp" line="2927"/>
         <source>State of the process </source>
-        <translation>Κατάσταση της διεργασίες </translation>
+        <translation>Κατάσταση των διεργασιών </translation>
     </message>
     <message>
         <location filename="../proc.cpp" line="2929"/>
@@ -1370,6 +1370,11 @@ exited with status </source>
         <source>Continue</source>
         <translation>Συνέχεια</translation>
     </message>
+    <message>
+        <location filename="../qps.cpp" line="477"/>
+        <source>Other Signals</source>
+        <translation>Άλλα σήματα</translation>
+    </message>
     <message>
         <location filename="../qps.cpp" line="478"/>
         <source>SIGINT (interrupt)</source>
@@ -1548,7 +1553,7 @@ exited with status </source>
     <message>
         <location filename="../qps.cpp" line="1524"/>
         <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
-        <translation></translation>
+        <translation>Δεν έχετε δικαίωμα αποστολής ενός σήματος στην διεργασία %1 (%2). Μόνον ο ο υπερχρήστης και ο ιδιοκτήτης της διεργασίας μπορούν αν στέλνουν σήματα σε αυτήν.</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="1909"/>
@@ -1627,12 +1632,12 @@ exited with status </source>
 <context>
     <name>SearchBox</name>
     <message>
-        <location filename="../misc.cpp" line="760"/>
+        <location filename="../misc.cpp" line="712"/>
         <source>PID, COMMAND, USER...</source>
         <translation>PID, ΕΝΤΟΛΗ, ΧΡΗΣΤΗΣ...</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="761"/>
+        <location filename="../misc.cpp" line="713"/>
         <source>Filter</source>
         <translation>Φίλτρο</translation>
     </message>
@@ -1752,7 +1757,7 @@ exited with status </source>
 <context>
     <name>StatusBar</name>
     <message>
-        <location filename="../misc.cpp" line="796"/>
+        <location filename="../misc.cpp" line="748"/>
         <source>Process count: %1</source>
         <translation></translation>
     </message>
