@@ -221,42 +221,42 @@ exited with status </source>
 <context>
     <name>ControlBar</name>
     <message>
-        <location filename="../misc.cpp" line="806"/>
+        <location filename="../misc.cpp" line="758"/>
         <source>Linear</source>
         <translation>リニア</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="809"/>
+        <location filename="../misc.cpp" line="761"/>
         <source>Tree</source>
         <translation>ツリー</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="818"/>
+        <location filename="../misc.cpp" line="770"/>
         <source>Thread</source>
         <translation>スレッド</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="825"/>
+        <location filename="../misc.cpp" line="777"/>
         <source>All Processes</source>
         <translation>すべてのプロセス</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="826"/>
+        <location filename="../misc.cpp" line="778"/>
         <source>Your Processes</source>
         <translation>自分のプロセス</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="827"/>
+        <location filename="../misc.cpp" line="779"/>
         <source>Non-Root Processes</source>
         <translation>Root 以外のプロセス</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="828"/>
+        <location filename="../misc.cpp" line="780"/>
         <source>Running Processes</source>
         <translation>実行中のプロセス</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="844"/>
+        <location filename="../misc.cpp" line="796"/>
         <source>Pause (Ctrl+Space)</source>
         <translation>一時停止 (Ctrl+Space)</translation>
     </message>
@@ -442,7 +442,7 @@ exited with status </source>
     <message>
         <location filename="../execwindow.cpp" line="104"/>
         <source>terminate command</source>
-        <translation type="unfinished"></translation>
+        <translation>コマンドを終了</translation>
     </message>
     <message>
         <location filename="../execwindow.cpp" line="113"/>
@@ -534,7 +534,7 @@ exited with status </source>
     <message>
         <location filename="../listmodel.cpp" line="66"/>
         <source>Event Category</source>
-        <translation type="unfinished"></translation>
+        <translation>イベントカテゴリ</translation>
     </message>
     <message>
         <location filename="../listmodel.cpp" line="68"/>
@@ -572,7 +572,7 @@ exited with status </source>
     <message>
         <location filename="../details.cpp" line="394"/>
         <source>Permission flags</source>
-        <translation type="unfinished"></translation>
+        <translation>パーミッションフラグ</translation>
     </message>
     <message>
         <location filename="../details.cpp" line="395"/>
@@ -1370,6 +1370,11 @@ exited with status </source>
         <source>Continue</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../qps.cpp" line="477"/>
+        <source>Other Signals</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../qps.cpp" line="478"/>
         <source>SIGINT (interrupt)</source>
@@ -1627,12 +1632,12 @@ exited with status </source>
 <context>
     <name>SearchBox</name>
     <message>
-        <location filename="../misc.cpp" line="760"/>
+        <location filename="../misc.cpp" line="712"/>
         <source>PID, COMMAND, USER...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="761"/>
+        <location filename="../misc.cpp" line="713"/>
         <source>Filter</source>
         <translation>フィルター</translation>
     </message>
@@ -1752,7 +1757,7 @@ exited with status </source>
 <context>
     <name>StatusBar</name>
     <message>
-        <location filename="../misc.cpp" line="796"/>
+        <location filename="../misc.cpp" line="748"/>
         <source>Process count: %1</source>
         <translation>プロセス数: %1</translation>
     </message>
