@@ -69,12 +69,12 @@
     <message>
         <location filename="../prefs.cpp" line="82"/>
         <source>Auto Save Settings on Exit</source>
-        <translation>종료 시 설정 자동 저장</translation>
+        <translation>종료 시 설정 자동 저장하기</translation>
     </message>
     <message>
         <location filename="../prefs.cpp" line="83"/>
         <source>Selection: Copy PIDs to Clipboard</source>
-        <translation>선택: 클립보드에 PID 복사</translation>
+        <translation>선택: 클립보드에 PID 복사하기</translation>
     </message>
     <message>
         <location filename="../prefs.cpp" line="85"/>
@@ -160,7 +160,7 @@ exited with status </source>
     <message>
         <location filename="../commanddialog.cpp" line="47"/>
         <source>Edit Commands 0.1 alpha</source>
-        <translation>명령 0.1 알파 편집</translation>
+        <translation>명령 0.1 알파 편집하기</translation>
     </message>
     <message>
         <location filename="../commanddialog.cpp" line="63"/>
@@ -205,12 +205,12 @@ exited with status </source>
         <location filename="../commanddialog.cpp" line="111"/>
         <location filename="../commanddialog.cpp" line="229"/>
         <source>Add...</source>
-        <translation>추가...</translation>
+        <translation>추가하기...</translation>
     </message>
     <message>
         <location filename="../commanddialog.cpp" line="113"/>
         <source>Delete</source>
-        <translation>삭제</translation>
+        <translation>삭제하기</translation>
     </message>
     <message>
         <location filename="../commanddialog.cpp" line="115"/>
@@ -221,42 +221,42 @@ exited with status </source>
 <context>
     <name>ControlBar</name>
     <message>
-        <location filename="../misc.cpp" line="806"/>
+        <location filename="../misc.cpp" line="758"/>
         <source>Linear</source>
         <translation>직선</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="809"/>
+        <location filename="../misc.cpp" line="761"/>
         <source>Tree</source>
         <translation>트리</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="818"/>
+        <location filename="../misc.cpp" line="770"/>
         <source>Thread</source>
         <translation>스레드</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="825"/>
+        <location filename="../misc.cpp" line="777"/>
         <source>All Processes</source>
         <translation>모든 프로세스</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="826"/>
+        <location filename="../misc.cpp" line="778"/>
         <source>Your Processes</source>
         <translation>사용자 프로세스</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="827"/>
+        <location filename="../misc.cpp" line="779"/>
         <source>Non-Root Processes</source>
         <translation>루트가 아닌 프로세스</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="828"/>
+        <location filename="../misc.cpp" line="780"/>
         <source>Running Processes</source>
         <translation>프로세스 실행 중</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="844"/>
+        <location filename="../misc.cpp" line="796"/>
         <source>Pause (Ctrl+Space)</source>
         <translation>일시 중지 (Ctrl+Space)</translation>
     </message>
@@ -372,7 +372,7 @@ exited with status </source>
     <message>
         <location filename="../watchdog.ui" line="342"/>
         <source>show Message</source>
-        <translation>메시지 표시</translation>
+        <translation>메시지 표시하기</translation>
     </message>
     <message>
         <location filename="../watchdog.ui" line="367"/>
@@ -394,12 +394,12 @@ exited with status </source>
     <message>
         <location filename="../watchdog.ui" line="432"/>
         <source>Add</source>
-        <translation>추가</translation>
+        <translation>추가하기</translation>
     </message>
     <message>
         <location filename="../watchdog.ui" line="439"/>
         <source>Delete</source>
-        <translation>삭제</translation>
+        <translation>삭제하기</translation>
     </message>
     <message>
         <location filename="../watchdog.ui" line="446"/>
@@ -1181,7 +1181,7 @@ exited with status </source>
     <message>
         <location filename="../proc.cpp" line="2950"/>
         <source>Root directory of process</source>
-        <translation>프로세스의 루트 디렉토리</translation>
+        <translation>프로세스의 루트 디렉터리</translation>
     </message>
     <message>
         <location filename="../proc.cpp" line="2953"/>
@@ -1199,7 +1199,7 @@ exited with status </source>
     <message>
         <location filename="../qps.cpp" line="1845"/>
         <source>Show</source>
-        <translation>표시</translation>
+        <translation>표시하기</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="1848"/>
@@ -1222,12 +1222,12 @@ exited with status </source>
     <message>
         <location filename="../qps.cpp" line="199"/>
         <source>Remove Field</source>
-        <translation>필드 제거</translation>
+        <translation>필드 제거하기</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="200"/>
         <source>Add Field</source>
-        <translation>필드 추가</translation>
+        <translation>필드 추가하기</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="207"/>
@@ -1297,7 +1297,7 @@ exited with status </source>
     <message>
         <location filename="../qps.cpp" line="265"/>
         <source>Show Status bar</source>
-        <translation>상태 표시줄 표시</translation>
+        <translation>상태 표시줄 표시하기</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="274"/>
@@ -1370,6 +1370,11 @@ exited with status </source>
         <source>Continue</source>
         <translation>계속하기</translation>
     </message>
+    <message>
+        <location filename="../qps.cpp" line="477"/>
+        <source>Other Signals</source>
+        <translation>기타 신호</translation>
+    </message>
     <message>
         <location filename="../qps.cpp" line="478"/>
         <source>SIGINT (interrupt)</source>
@@ -1458,17 +1463,17 @@ exited with status </source>
     <message>
         <location filename="../qps.cpp" line="781"/>
         <source>Show File Path</source>
-        <translation>파일 경로 표시</translation>
+        <translation>파일 경로 표시하기</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="787"/>
         <source>Show Graph</source>
-        <translation>그래프 표시</translation>
+        <translation>그래프 표시하기</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="793"/>
         <source>Show Control Bar</source>
-        <translation>제어 막대 표시</translation>
+        <translation>제어 막대 표시하기</translation>
     </message>
     <message>
         <location filename="../qps.cpp" line="804"/>
@@ -1627,12 +1632,12 @@ exited with status </source>
 <context>
     <name>SearchBox</name>
     <message>
-        <location filename="../misc.cpp" line="760"/>
+        <location filename="../misc.cpp" line="712"/>
         <source>PID, COMMAND, USER...</source>
         <translation>PID, 명령, 사용자...</translation>
     </message>
     <message>
-        <location filename="../misc.cpp" line="761"/>
+        <location filename="../misc.cpp" line="713"/>
         <source>Filter</source>
         <translation>필터</translation>
     </message>
@@ -1752,7 +1757,7 @@ exited with status </source>
 <context>
     <name>StatusBar</name>
     <message>
-        <location filename="../misc.cpp" line="796"/>
+        <location filename="../misc.cpp" line="748"/>
         <source>Process count: %1</source>
         <translation>프로세스 수: %1</translation>
     </message>
